@@ -10,10 +10,10 @@
 #define GDKMM_MAJOR_VERSION 4
 
 /* Minor version number of gdkmm. */
-#define GDKMM_MINOR_VERSION 0
+#define GDKMM_MINOR_VERSION 4
 
 /* Micro version number of gdkmm. */
-#define GDKMM_MICRO_VERSION 1
+#define GDKMM_MICRO_VERSION 0
 
 /* Enable DLL-specific stuff only when not building a static library */
 #if !defined(__CYGWIN__) && defined(_WIN32) && !defined(GDKMM_STATIC_LIB)
@@ -23,8 +23,10 @@
 #ifdef GDKMM_DLL
 # if defined (GDKMM_BUILD) || defined (GTKMM_BUILD)
 #  define GDKMM_API __declspec(dllexport)
-# else
+# elif !defined (__GNUC__)
 #  define GDKMM_API __declspec(dllimport)
+# else /* don't dllimport classes/methods on GCC/MinGW */
+#  define GDKMM_API
 # endif /* GDKMM_BUILD */
 #else
 /* Build a static library or a non-native-Windows library */
