@@ -10,10 +10,10 @@
 #define GTKMM_MAJOR_VERSION 4
 
 /* Minor version number of gtkmm. */
-#define GTKMM_MINOR_VERSION 0
+#define GTKMM_MINOR_VERSION 4
 
 /* Micro version number of gtkmm. */
-#define GTKMM_MICRO_VERSION 1
+#define GTKMM_MICRO_VERSION 0
 
 /* Define when building gtkmm as a static library. */
 /* #undef GTKMM_STATIC_LIB */
@@ -26,8 +26,10 @@
 #ifdef GTKMM_DLL
 # if defined (GDKMM_BUILD) || defined(GTKMM_BUILD)
 #  define GTKMM_API __declspec(dllexport)
-# else
+# elif !defined (__GNUC__)
 #  define GTKMM_API __declspec(dllimport)
+# else /* don't dllimport classes/methods on GCC/MinGW */
+#  define GTKMM_API
 # endif
 #else
 /* Build a static library or a non-native Windows library */
